qq(x, data, ...)## S3 method for class 'formula':
qq(x, data, aspect = "fill",
panel = lattice.getOption("panel.qq"),
prepanel, scales, strip,
groups, xlab, xlim, ylab, ylim, f.value = NULL,
drop.unused.levels = lattice.getOption("drop.unused.levels"),
...,
lattice.options = NULL,
qtype = 7,
default.scales = list(),
default.prepanel = lattice.getOption("prepanel.default.qq"),
subscripts,
subset)
For the "formula" method, x should be a formula of the
form y ~ x | g1 * g2 * ..., where x should be a
numeric variable, and y
formula method, an optional data source (usually a
data frame) in which variables are to be evaluated (see
xyplot for details).panel.qq is documented
separatype argument for quantile.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot.xyplot
for non-trivial details.qq produces Q-Q plots of two samples. The default behaviour of
qq is different from the corresponding S-PLUS function. See the
entry for f.value for specifics. This and all other high level Trellis functions have several
arguments in common. These are extensively documented only in the
help page for xyplot, which should be consulted to learn more
detailed usage.
xyplot, panel.qq,
qqmath, Latticeqq(voice.part ~ height, aspect = 1, data = singer,
subset = (voice.part == "Bass 2" | voice.part == "Tenor 1"))Run the code above in your browser using DataLab