Learn R Programming

lattice (version 0.19-30)

C_04_lattice.options: Low-level Options Controlling Behaviour of Lattice

Description

Functions to handle settings used by lattice. Their main purpose is to make code maintainance easier, and users normally should not need to use these functions. However, fine control at this level maybe useful in certain cases.

Usage

lattice.options(...)
lattice.getOption(name)

Arguments

Value

lattice.getOption returns the value of a single component, whereas lattice.options always returns a list with one or more named components. When changing the values of components, the old values of the modified components are returned by lattice.options. If called without any arguments, the full list is returned.

Details

These functions are modeled on options and getOption, and behave similarly for the most part. Some of the available components are documented here, but not all. The purpose of the ones not documented are either fairly obvious, or not of interest to the end-user.

[object Object],[object Object],[object Object],[object Object],[object Object]

See Also

options, trellis.device, trellis.par.get, Lattice

Examples

Run this code
names(lattice.options())
str(lattice.getOption("layout.widths"))

Run the code above in your browser using DataLab