barchart.panel.barchart(x, y, box.ratio = 1, box.width,
horizontal = TRUE,
origin = NULL, reference = TRUE,
stack = FALSE,
groups = NULL,
col = if (is.null(groups)) plot.polygon$col
else superpose.polygon$col,
border = if (is.null(groups)) plot.polygon$border
else superpose.polygon$border,
lty = if (is.null(groups)) plot.polygon$lty
else superpose.polygon$lty,
lwd = if (is.null(groups)) plot.polygon$lwd
else superpose.polygon$lwd,
..., identifier = "barchart")origin is specified, in which case they start there.box.ratio. Useful for specifying thickness when the
categorical variable is not a factor, as use of box.ratio
alone cannot achieve a thickness greater than 1.<stack = TRUE, this argument is ignored and the origin set to
0. Otherwise, defaults to NULL, in which case bars start at
the left (or bottom) end of a panel. This FALSE (the default), bars for different values of the
grouping variable are drawn side by side, otherwise they are
stacked.plot.polygon is used if there is no grouping variable, otherwise
superpose.polygon is used. col gives the fill color,
borderbarchart call
directly.barchartbarchart(yield ~ variety | site, data = barley,
groups = year, layout = c(1,6), origin = 0,
ylab = "Barley Yield (bushels/acre)",
scales = list(x = list(abbreviate = TRUE,
minlength = 5)))Run the code above in your browser using DataLab