Learn R Programming

lattice (version 0.19-30)

F_1_panel.parallel: Default Panel Function for parallel

Description

This is the default panel function for parallel.

Usage

panel.parallel(x, y, z, subscripts,
               groups = NULL,
               col, lwd, lty, alpha,
               common.scale = FALSE,
               lower,
               upper,
               ...,
               horizontal.axis = TRUE,
               identifier = "parallel")

Arguments

Details

Produces parallel coordinate plots, which are easier to understand from an example than through a verbal description. See example for parallel

References

Inselberg, Alfred (2009) Parallel Coordinates: Visual Multidimensional Geometry and Its Applications, Springer. ISBN: 978-0-387-21507-5.

Inselberg, A. (1985) The Plane with Parallel Coordinates, The Visual Computer.

See Also

parallel