panel.loess(x, y, span = 2/3, degree = 1, family = c("symmetric", "gaussian"), evaluation = 50, lwd, lty, col, col.line, type, horizontal = FALSE, ..., identifier = "loess")col.line overrides col. type argument (perhaps meant for
another function) does not affect the display. loess.smooth, for which panel.loess is
essentially a wrapper.
x) and which as the response (by
default y). If TRUE, the plot is transposed
in the sense that y becomes the predictor and x the
response. (The name horizontal may seem an odd choice for
this argument, and originates from similar usage in
bwplot).
panel.lines.
loess.smooth.
loess.smooth,
prepanel.loess