Learn R Programming

lattice (version 0.19-30)

F_2_panel.spline: Panel Function to Add a Spline Smooth

Description

A predefined panel function that can be used to add a spline smooth based on the provided data.

Usage

panel.spline(x, y, npoints = 101,
             lwd = plot.line$lwd,
             lty = plot.line$lty,
             col, col.line = plot.line$col,
             type,
             horizontal = FALSE, ...,
             keep.data = FALSE,
             identifier = "spline")

Arguments

Value

The fitted model as returned by smooth.spline.

See Also

Lattice, smooth.spline, prepanel.spline