xyplot to parse the formula argument and evaluate various
components of the data.
latticeParseFormula(model, data, dimension = 2, subset = TRUE, groups = NULL, multiple, outer, subscripts, drop)dimension argument. The 2d formulas are of the form
y ~ x| g1 * ... *gn, and the 3d formulas are of the form
z ~ x * y | g1 * ...* gn. In the first form, y may
be omitted. The conditioning variables g1, ...,gn can be
omitted in either case.
xyplot for details
drop.unused.levels argument
in xyplot, indicating whether unused levels of
conditioning factors and data variables that are factors are to be
dropped.
left,
right, left.name, right.name, condition for 2-D, and left,
right.x, right.y, left.name, right.x.name, right.y.name, condition
for 3-D. Other possible components are groups, subscrxyplot, Lattice