Learn R Programming

lattice (version 0.20-33)

H_melanoma: Melanoma skin cancer incidence

Description

These data from the Connecticut Tumor Registry present age-adjusted numbers of melanoma skin-cancer incidences per 100,000 people in Connectict for the years from 1936 to 1972.

Usage

melanoma

Arguments

Format

A data frame with 37 observations on the following 2 variables.
year
Years 1936 to 1972.
incidence
Rate of melanoma cancer per 100,000 population.

Houghton, A., E. W. Munster, and M. V. Viola. (1978). Increased Incidence of Malignant Melanoma After Peaks of Sunspot Activity. The Lancet, 8, 759--760.

References

Cleveland, William S. (1993) Visualizing Data. Hobart Press, Summit, New Jersey.

Examples

Run this code
# Time-series plot.  Figure 3.64 from Cleveland.
xyplot(incidence ~ year,
  data = melanoma,
	aspect = "xy",
	panel = function(x, y)
		panel.xyplot(x, y, type="o", pch = 16),
	ylim = c(0, 6),
	xlab = "Year",
	ylab = "Incidence")

Run the code above in your browser using DataLab