| G latticeParseFormula | R Documentation |
this function is used by high level Lattice functions such as
xyplot to parse the formula argument and evaluate various
components of the data.
latticeParseFormula(model, data, dimension = 2,
subset = TRUE, groups = NULL,
multiple, outer,
subscripts, drop, case.names)
model |
the model/formula to be parsed. This can be in either of two
possible forms, one for 2d and one for 3d formulas, determined by
the |
data |
the environment/dataset where the variables in the formula are evaluated. |
dimension |
dimension of the model, see above. |
subset |
index for choosing a subset of the data frame. |
groups |
the grouping variable, if present. |
multiple, outer |
logicals, determining how a ‘+’ in the y and x components of
the formula are processed. See |
subscripts |
logical, whether subscripts are to be calculated. |
drop |
logical or list, similar to the |
case.names |
either a logical, or a character string giving case names. If
|
Returns a list with several components, including left, right,
left.name, right.name, condition for 2-D, and left, right.x,
right.y, left.name, right.x.name, right.y.name, condition for
3-D. Other possible components are groups, subscr, and
case.names.
Saikat DebRoy, Deepayan Sarkar Deepayan.Sarkar@R-project.org
xyplot, Lattice
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.