reorderFactor(x, X, FUN = mean, ...,
order = is.ordered(x))x, whose subset
of values for each unique level of x determines the
eventual order of that levelX
determined by the levels of xFUNorder), with the order of the levels determined by
FUN applied to X grouped by x. The
levels are ordered such that the values returned by FUN
are in increasing order.xyplot, Lattice