This class of objects is returned by high level lattice functions, and
is usually plotted by default by its
print method.
xyplot, is a list with the "class" attribute set
to "trellis". Many of the components of this list are simply
the arguments to the high level function that produced the object.
Among them are: as.table, layout, page,
panel, prepanel, main, sub,
par.strip.text, strip, skip, xlab
ylab, par.settings, lattice.options and
plot.args. Some other typical components are:
formula
index.cond
perm.cond
aspect.fillaspect is "fill"
aspect.ratioaspect.fill is
FALSE
call
condlevels
legend
panel.args
panel.args.commonname=value form
x.scales"same"
y.scalesx.scales
x.between
y.between
x.limits
y.limitsx.limits
packet.sizes
Lattice, xyplot,
print.trellis