splom.panel.pairs(z,
panel = lattice.getOption("panel.splom"),
lower.panel = panel,
upper.panel = panel,
diag.panel = "diag.panel.splom",
as.matrix = FALSE,
groups = NULL,
panel.subscripts,
subscripts,
pscales = 5,
prepanel.limits = scale.limits,
varnames = colnames(z),
varname.col, varname.cex, varname.font,
varname.fontfamily, varname.fontface,
axis.text.col, axis.text.cex, axis.text.font,
axis.text.fontfamily, axis.text.fontface,
axis.text.lineheight,
axis.line.col, axis.line.lty, axis.line.lwd,
axis.line.alpha, axis.line.tck,
...)
diag.panel.splom(x = NULL,
varname = NULL, limits, at = NULL, labels = NULL,
draw = TRUE, tick.number = 5,
varname.col, varname.cex,
varname.lineheight, varname.font,
varname.fontfamily, varname.fontface,
axis.text.col, axis.text.alpha,
axis.text.cex, axis.text.font,
axis.text.fontfamily, axis.text.fontface,
axis.text.lineheight,
axis.line.col, axis.line.alpha,
axis.line.lty, axis.line.lwd,
axis.line.tck,
...)lower.panel and upper.panel are used for
panels below and above the diagonal respectively.In addition to extra arguments not recognized by
diag.panel.splom to know what arguments this function is
passed when called.TRUE, the layout of the panels will have origin
on the top left instead of bottom left (similar to
pairs). This is in essence the same functionality as provided
by as.table for the panel layousubscripts.z that are to be
displayed in this (super)panel.splom.
If pscales is a single number, it indicates the approximate
number of equally-spaced ticks that should appear on each axis. If
pscales is a list, it should hx containing a data vector. The return value of the function
should be similar to the xlim or ylim argument
documented in FALSE, variable names are shown but axis annotation is
omitted.x. By default, the column names of x.gpar for details on this and the
other graphical parameters listed below.panel, lower.panel,
upper.panel, and diag.panel from panel.pairs.
Currently ignored by diag.panel.splom.panel.pairs is the function that is actually used as the panel
function in a "trellis" object produced by splom.splomCmat <- outer(1:6,1:6,
function(i,j) rainbow(11, start=.12, end=.5)[i+j-1])
splom(~diag(6), as.matrix = TRUE,
panel = function(x, y, i, j, ...) {
panel.fill(Cmat[i,j])
panel.text(.5,.5, paste("(",i,",",j,")",sep=""))
})Run the code above in your browser using DataLab