panel.spline(x, y, npoints = 101, lwd = plot.line$lwd, lty = plot.line$lty, col, col.line = plot.line$col, type, horizontal = FALSE, ..., keep.data = FALSE, identifier = "spline")col.line overrides col. type argument (perhaps meant for
another function) does not affect the display. x) and which as the response (by
default y). If TRUE, the plot is transposed
in the sense that y becomes the predictor and x the
response. (The name horizontal may seem an odd choice for
this argument, and originates from similar usage in
bwplot).
smooth.spline. The
default here (FALSE) is different, and results in the
original data not being retained in the fitted spline model. It may
be useful to set this to TRUE if the return value of
panel.spline, which is the fitted model as returned by
smooth.spline, is to be used for subsequent
computations. smooth.spline and panel.lines as
appropriate. smooth.spline.
smooth.spline,
prepanel.spline