x (and
y where appropriate) variables are plotted with different
graphical parameters for each distinct value of the grouping variable.panel.superpose(x, y = NULL, subscripts, groups,
panel.groups = "panel.xyplot",
...,
col, col.line, col.symbol,
pch, cex, fill, font,
fontface, fontfamily,
lty, lwd, alpha,
type = "p", grid = FALSE,
distribute.type = FALSE)
panel.superpose.2(..., distribute.type = TRUE)panel.superpose.plain(...,
col, col.line, col.symbol,
pch, cex, fill, font,
fontface, fontfamily,
lty, lwd, alpha)
panel.superpose divides up the x (and optionally
y) variable(s) by the unique values of
groups[subscripts], and plots each subset with different
graphical parameters. The graphical parameters (col.symbol,
pch, etc.) are usually supplied as suitable atomic vectors, but
can also be lists. When panel.groups is called for the
i-th level of groups, the corresponding element of each
graphical parameter is passed to it. In the list form, the individual
components can themselves be vectors. The actual plot for each subgroup is created by the
panel.groups function. With the default panel.groups,
the col argument is overridden by col.line and
col.symbol for lines and points respectively, which default to
the "superpose.line" and "superpose.symbol" settings.
However, col will still be supplied as an argument to
panel.groups functions that make use of it, with a default of
"black". The defaults of other graphical parameters are also
taken from the "superpose.line" and "superpose.symbol"
settings as appropriate. The alpha parameter takes it default
from the "superpose.line" setting.
panel.superpose and panel.superpose.2 differ essentially
in how type is interpreted by default. The default behaviour
in panel.superpose is the opposite of that in S, which is the
same as that of panel.superpose.2.
panel.superpose.plain is the same as panel.superpose,
except that the default settings for the style arguments are the
same for all groups and are taken from the default plot style.
It is used in xyplot.ts.
panel.groups gives different
types of plots, for example panel.xyplot,
panel.dotplot and panel.linejoin (This can
be used to produce interaction plots). See Lattice for an overview of the package.