prepanel.lmline(x, y, ...)
prepanel.qqmathline(x, y = x, distribution = qnorm,
probs = c(0.25, 0.75), qtype = 7,
groups, subscripts,
...)
prepanel.loess(x, y, span, degree, family, evaluation,
horizontal = FALSE, ...)
prepanel.spline(x, y, npoints = 101,
horizontal = FALSE, ...,
keep.data = FALSE)xlim, ylim, dx and
dy, the first two being used to calculate panel axes limits,
the last two for banking computations. The form of these components
are described under xyplot. There are also several
prepanel functions that serve as the default for high level functions,
see prepanel.default.xyplot In addition, prepanel.lmline computes the dx and
dy such that it reflects the slope of the linear regression
line; for prepanel.qqmathline, this is the slope of the line
passing through the quantile pairs specified by probs. For
prepanel.loess and prepanel.spline, dx and
dy reflect the piecewise slopes of the nonlinear smooth.
xyplot, banking,
panel.loess, panel.spline.