This implementation depends heavily on a new Graphics engine (Grid) for
R being developed by Paul Murrell. Knowledge of Grid is not necessary
for using Lattice (except when writing new panel functions), but for
one important aspect: Grid (and hence Lattice) graphics do not
mix with conventional R Graphics. The way to use both is to enclose
any Grid graphics commands by calls to grid.start and
grid.stop. Note that library(lattice) automatically calls
grid.start.
Type library(help = lattice) to see a list of (public)
Lattice graphics functions.
trellis.args. To learn how to customise the Graphical parameters used by the Lattice
functions, see trellis.settings.
To learn how to initialise new devices or change the settings of the
current device, see trellis.device
To learn about sophisticated (non-default) printing capabilities, see
print.trellis.
Here is a list of `high level' functions in the Lattice library with a brief description of what they do:
Univariate:
barchart bar plots
bwplot box and whisker plots
densityplot kernel density plots
dotplot dot plots
histogram histograms
qqmath quantile plots against mathematical distributions
stripplot 1-dimensional scatterplot
Bivariate:
qq q-q plot for comparing two distributions
xyplot scatter plot (and possibly a lot more)
Hypervariate:
splom scatterplot matrix
parallel parallel coordinate plots
Miscellaneous: