Usage
cloud(formula,
data,
subpanel = "panel.xyplot",
aspect = c(1, 1),
scales = list(cex = 0.5, lty = 1, lwd = 1,
col = "black", distance = rep(1, 3),
arrows = TRUE),
zlab,
zlim = range(z),
distance = 0.2,
par.box,
perspective = TRUE,
R.mat = diag(4),
screen = list(z = 40, x = -60),
zoom = 1,
...)Arguments
formula
a formula of the form z ~ x * y | g1 * g2 *
...
data
data frame in which variables are evaluated
subpanel
the function used to plot the points once coordinates
of their projections are computed. subpanel="panel.superpose"
along with the groups argument can be used to create grouped
displays. See iris example below
aspect
vector of length 2, giving the relative aspects of the
y-size/x-size and z-size/x-size of the enclosing rectangle.
scales
describes scales. not used yet
distance
between 0 and 1, controls amount of perspective. No
connection with the physical concept of distance in this
implementation (not clear what S+ does). individual values don't give
the same results as S-Plus, but all instances should be achievab
par.box
graphical parameters for box, not implemented yet
perspective
logical, whether to plot a perspective view
R.mat
initial rotation matrix (homogeneous coordinates). Not
implemented.
screen
A list determining the rotations to applied to the data
before being plotted. The initial position starts with the view
somewhere in the positive z-axis, and the x and y axes in the usual
position. Each component of the list should be named on
zoom
factor by which to scale the picture.
synopsis
cloud(formula, data = parent.frame(), aspect = c(1, 1), layout = NULL,
panel = "panel.cloud", subpanel = "panel.xyplot", prepanel = NULL,
scales = list(cex = 0.5, lty = 1, lwd = 1, col = "black",
distance = rep(1, 3), arrows = TRUE), strip = TRUE, groups = NULL,
xlab, xlim = range(x), ylab, ylim = range(y), zlab, zlim = range(z),
distance = 0.2, par.box, perspective = TRUE, R.mat = diag(4),
screen = list(z = 40, x = -60), zoom = 1, ..., subscripts = TRUE,
subset = TRUE)