Learn R Programming

lattice (version 0.4-0)

lset: Simple Interfaces to modify Trellis Settings and Lattice Themes

Description

These functions are simple interfaces to do some of the more common tasks that can be achieved by trellis.par.get/set. These are NOT S-compatible

Usage

lset(theme = c("col.bg", "white.bg", "bw"), file)
lset.textfont(xlab, ylab, main, sub, add)
lset.textcol(xlab, ylab, main, sub, add)
lset.textcex(xlab, ylab, main, sub, add)

Arguments

file
the name of a file that will be source()d.
theme
a character string specifying the name of a predefined `theme'. This is at a very early stage of development, and not many interesting themes are available yet.
xlab, ylab, main, sub, add
intended replacement values for respective components of trellis.settings

Details

These functions are meant to be interfaces to trellis.settings. lset deals with the whole list of settings. lset.text* modifies components of the various text components. More similar functions should come later.

lset implements a concept of `themes' in Lattice. Themes are predefined values of trellis.settings that modify the overall look. The only current theme significantly different from the defaults is the "white.bg" theme, which hopefully

See Also

trellis.settings, Lattice