packet.panel.default: Associating Packets with Panels
Description
When a "trellis" object is plotted, panels are always drawn in
an order such that columns vary the fastest, then rows and then pages.
An optional function can be specified that determines, given the
column, row and page and other relevant information, the packet (if
any) which should be used in that panel. The function documented here
implements the default behaviour, which is to match panel order with
packet order, determined by varying the first conditioning variable
the fastest, then the second, and so on. This matching is performed
after any reordering and/or permutation of the conditioning variables.Usage
packet.panel.default(layout, condlevels, page, row, column,
skip, all.pages.skip = TRUE)Value
A suitable combination of levels of the conditioning variables in the
form of a numeric vector as long as the number of conditioning
variables, with each element an integer indexing the levels of the
corresponding variable. Specifically, if the return value is
p, then the i-th conditioning variable will have level
condlevels[[i]][p[i]].