Learn R Programming

lattice (version 0.4-0)

panel.densityplot: Default Panel Function for densityplot

Description

This is the default panel function for densityplot.

Usage

panel.densityplot(x, darg, plot.points = TRUE, ref = FALSE, ...)

Arguments

x
data points for which density is to be estimated
darg
list of arguments to be passed to the density function. Typically, this should be a list with some of the following components : bw,adjust, kernel, window, width, give.Rkern, n, from, to, cut, na.rm (see density for
plot.points
logical, specifying whether or not the data points should be plotted along with the estimated density. The default (TRUE) is S-Plus behaviour.
ref
logical, whether to draw x-axis
...
parameters to be passed to the function density, as well as graphical parameters like col

See Also

densityplot