panel.abline(a, b, ...)
panel.abline(coef, ...)
panel.abline(reg, ...)
panel.abline(h= ,v= , ...)
panel.curve(expr, from, to, n = 101,
curve.type = "l", ...)
panel.rug(x = NULL, y = NULL,
regular = TRUE, start, end, ...)
panel.fill(col="grey", ...)
panel.grid(h=3, v=3, ...)
panel.lmline(x,y,...) = panel.abline(lm(y~x), ...)
panel.loess(x, y, span = 2/3, degree = 1,
family = c("symmetric", "gaussian"),
evaluation = 50, ...)
panel.linejoin(x, y, fun = mean, horizontal = TRUE, ...)
panel.mathdensity(dmath = dnorm, args = list(mean=0, sd=1))panel.abline adds a line of the form y=a+bx or vertical
and/or horizontal lines. Graphical parameters are obtained from
reference.line for panel.grid, and add.line for the
others (can be set using trellis.par.set ) panel.curve adds a curve, similar to what curve does
with add = TRUE. Graphical parameters for the line are obtained
from the add.line setting.
panel.linejoin treats one of x and y as a factor (according to
the value of horizontal, calculates fun applied to the
subsets of the other variable determined by each unique value of the
factor, and joins them by a line. Can be used in conjunction with
panel.xyplot and more commonly with panel.superpose to produce
interaction plots. See xyplot documentation for an example.
panel.mathdensity plots a (usually theoretical) probability
density function. Can be useful in conjunction with histogram
and densityplot to visually estimate goodness of fit.
panel.axis draws axis tick marks INSIDE a panel. It honours the
(native) axis scales within the panel, but the locations need to be
explicitly specified. Used in panel.pairs for
splom.
panel.identify is similar to identify. When
called as part of the panel function, it waits for the user to
identify points (in the panel being drawn) via mouse clicks.
Clicks other than left-clicks terminate the procedure. It is less
sophisticated than identify in the sense that it does not keep
track of points already identified.
loess.smooth,
identify, trellis.par.get