panel.number: Accessing Auxiliary Information During Plotting
Description
Control over lattice plots are provided through a collection of user
specifiable functions that perform various tasks during the plotting.
Not all information is available to all functions. The functions
documented here attempt to provide a consistent interface to access
relevant information from within these user specified functions,
namely those specified as the panel, strip and
axis functions.Usage
panel.number()
packet.number()
which.packet()
Value
panel.number returns an integer counting which panel is being
drawn (starting from 1 for the first panel, a.k.a. the panel order).
packet.number gives the packet number according to the packet
order, which is determined by varying the first conditioning variable
the fastest, then the second, and so on. which.packet returns
the combination of levels of the conditioning variables in the form of
a numeric vector as long as the number of conditioning variables, with
each element an integer indexing the levels of the corresponding
variable.