prepanel.functions: Useful Prepanel Function for Lattice
Description
These are predefined prepanel functions available in Lattice.Usage
prepanel.lmline(x, y, ...)
prepanel.loess(x, y, ...)
prepanel.qqmathline(y, distribution, f.value = ppoints, ...)
Arguments
x, y
x and y values, numeric or factor
distribution
quantile function for theoretical
distribution. This is automatically passed in when this is used as a
prepanel function in qqmath.
Value
- usually a list with components
xlim, ylim, dx and
dy, the first two being used to calculate panel axes limits,
the last two for banking computations. The form of these components
are described under xyplot. There are also several
undocumented prepanel functions that serve as the default for high
level functions, e.g., prepanel.default.xyplot
synopsis
prepanel.loess(x, y, span, degree, family, evaluation, ...)