prepanel.lmline(x, y, ...)
prepanel.loess(x, y, span, degree, family, evaluation, ...)
prepanel.qqmathline(x, y = x, distribution = qnorm,
p = c(0.25, 0.75), qtype = 7,
groups, subscripts,
...)xlim, ylim, dx and
dy, the first two being used to calculate panel axes limits,
the last two for banking computations. The form of these components
are described under xyplot. There are also several
undocumented prepanel functions that serve as the default for high
level functions, e.g., prepanel.default.xyplottrellis.par.get, xyplot,
banking, Lattice. See
loess.smooth for further options to
prepanel.loess