shingle(x, intervals=sort(unique(x)))
equal.count(x, ...)
as.shingle(x)
is.shingle(x)
## S3 method for class 'shingle':
plot(x, panel, xlab = "Range", ylab = "Panel", \dots)
## S3 method for class 'shingle':
print(x, showValues = TRUE, \dots)
## S3 method for class 'shingleLevel':
print(x, \dots)
## S3 method for class 'shingle':
summary(object, \dots)
## S3 method for class 'shingle':
as.data.frame(x, row.names = NULL, optional = FALSE)
## S3 method for class 'shingle':
[(x, subset, drop = FALSE)
as.factorOrShingle(x, subset, drop)x$intervals for levels.shingle(x),
logical for is.shingle, an object of class "trellis" for
plot (printed by default by print.trellis), and
an object of class "shingle" for the others.levels and
nlevels functions, usually applicable to factors, also work on
shingles. The implementation of shingles is slightly different from
S. There are print methods for shingles, as well as for printing the
result of levels() applied to a shingle.
equal.count converts x to a shingle. Essentially a
wrapper around co.intervals. All arguments are passed to
co.intervals
shingle creates a shingle using the given intervals. If
intervals is a vector, these are used to form 0 length
intervals.
as.shingle returns shingle(x) if x is not a
shingle.
is.shingle tests whether x is a shingle.
plot.shingle displays the ranges of shingles via
rectangles. print.shingle and summary.shingle describe
the shingle object.
xyplot,
co.intervals, Latticez <- equal.count(rnorm(50))
plot(z)
print(z)
print(levels(z))
<testonly>data.frame(x = equal.count(rnorm(100)), y = rnorm(100))</testonly>Run the code above in your browser using DataLab