A shingle is a data structure used in Trellis, and is meant to be a
generalization of factors to `continuous' variables. It consists of a
numeric vector along with some possibly overlapping intervals. These
intervals are the `levels' of the shingle. The levels and
nlevels functions, usually applicable to factors, are also
applicable to shingles. There are print methods for shingles, as well as for printing the
result of levels() applied to a shingle.
The implementation of shingles is slightly different from S.
equal.count converts x to a shingle. Essentially a
wrapper around co.intervals. All arguments are passed to
co.intervals
shingle creates a shingle using the given intervals. If
intervels is a vector, these are used to form 0 length
intervals.
as.shingle returns shingle(x) if x is not a
shingle.
is.shingle tests whether x is a shingle.
plot.shingle displays the ranges of shingles via
rectangles. print.shingle and summary.shingle describe
the shingle object.