Learn R Programming

lattice (version 0.4-0)

trellis.device: Initializing Trellis Displays

Description

trellis.device initializes a Trellis display device with appropriate settings of the graphics control parameter trellis.settings.

Usage

trellis.device(device, color = T, bg, new = T, first = FALSE, ...)

Arguments

device
name of a function (possibly as a character string) that initializes a device. Admissible values include "x11", "windows", "mac", "postscript", "pdf", "png" etc.
color
whether the display should be color or black and white.
bg
background color for the device. Can be changed by par(bg=).
new
logical flag indicating whether a new device should be startted. If new = F is specified, then the options for the current device are changed to the defaults determined by the other arguments.
first
logical controlling whether the first page should be blank. If first is FALSE (the default), then the first page on the new device will be left blank. If first is TRUE, then the first page will be used. However, this
...
additional parameters to be passed to the device function.

Details

trellis.device calls the device function to start a display, and sets the global variable trellis.settings to either of two possible values depending on whether color is set, and initializes the underlying Grid display.

trellis.settings can subsequently be handled by the interface functions trellis.par.get and trellis.par.set (also the fledgling lset interface).

See Also

trellis.par.set, Grid, lset, postscript,x11, Lattice