trellis.device initializes a Trellis display device with
appropriate settings of the graphics control parameter
trellis.settings.trellis.device(device, color = T, bg, new = T, first = FALSE, ...)new = F is specified, then the options for the
current device are changed to the defaults determined by the other
arguments.first is FALSE (the default), then the first page on
the new device will be left blank. If first is TRUE, then
the first page will be used. However, this device
function.trellis.device calls the device function to start a
display, and sets the global variable trellis.settings to
either of two possible values depending on whether color is
set, and initializes the underlying Grid display. trellis.settings can subsequently be handled by the
interface functions trellis.par.get and trellis.par.set
(also the fledgling lset interface).
trellis.par.set, Grid,
lset,
postscript,x11, Lattice